salmon88.fig7 <- within(list(),{
  data.path="Common/Salmon_1988_Fig7"
  xaxis <- read.table(
    file=sprintf('%s/Salmon_88_Fig7_Meas_Xaxis.xls', data.path),
    header=T)
  
  yaxis <- read.table(
    file=sprintf('%s/Salmon_88_Fig7_Meas_Yaxis.xls', data.path),
    header=T)

  xaxis$conc <- c(0,5,10,15,20)
  yaxis$freq <- c(0.008, 0.006, 0.004, 0.002, 0.0)
  
  x.scale <- lm(conc~X, xaxis)
  y.scale <- lm(freq~Y, yaxis)
  
  plus.end <- read.table(
    file=sprintf('%s/Salmon_88_Fig7_Meas_PlusEnds.xls', data.path),
    header=T)

  minus.end <- read.table(
    file=sprintf('%s/Salmon_88_Fig7_Meas_MinusEnds.xls', data.path),
    header=T)
  
  plus.end <- mutate(plus.end, 
                     X0 = X, 
                     Y0 = Y,
                     X = X + Width/2,
                     Y = Y + Height/2)
  minus.end <- mutate(minus.end,
                      X0 = X,
                      Y0 = Y,
                      X = X + Width/2,
                      Y = Y + Height/2)
  
  plus.end$conc <- predict.lm(x.scale, plus.end)
  plus.end$freq <- predict.lm(y.scale, plus.end)
  
  minus.end$conc <- predict.lm(x.scale, minus.end)
  minus.end$freq <- predict.lm(y.scale, minus.end)
  
  plus.end$vg <- 0.33*plus.end$conc - 1.6
  plus.end$length.to.cata <- (plus.end$vg/60) / plus.end$freq
  plus.end$time.to.cata <- 1/plus.end$freq
  plus.end$dimers.to.cata <- plus.end$length.to.cata * 1625
  
  minus.fit <- read.table(
    file=sprintf('%s/Salmon_88_Fig7_Meas_MinusEndFit.xls', data.path),
    header=T
  )
  
  minus.fit.pix <- data.frame(
    X=c(minus.fit$X, minus.fit$X+minus.fit$Width),
    Y=c(minus.fit$Y, minus.fit$Y+minus.fit$Height))
  minus.fit.xy <- data.frame(
    conc=predict.lm(x.scale, minus.fit.pix),
    freq=predict.lm(y.scale, minus.fit.pix))
  
  minus.fit.slope <- diff(minus.fit.xy$freq)/diff(minus.fit.xy$conc)
  minus.fit.intercept <- minus.fit.xy$freq[[1]] - minus.fit.slope * minus.fit.xy$conc[[1]]
  
  minus.end$fit.freq <- minus.end$conc * minus.fit.slope + minus.fit.intercept
})

salmon88.fig8 <- within(list(), {
  data.path="Common/Salmon_1988_Fig8"
  axis.x <- read.table(file=sprintf("%s/x-axis-rois.xls",data.path), header=T)
  axis.y <- read.table(file=sprintf("%s/y-axis-rois.xls",data.path), header=T)
  axis.x$conc <- c(0,5,10,15,20)
  axis.y$freq <- c(0.0, 0.1, 0.2, 0.3, 0.4, 0.5)

  scale.x <- lm(conc~X, axis.x)
  scale.y <- lm(freq~Y, axis.y)

  plus.end  <- read.table(file=sprintf("%s/plus-end-rois.xls",data.path),header=T)
  minus.end <- read.table(file=sprintf("%s/minus-end-rois.xls",data.path),header=T)

  plus.end <- within(plus.end, {
    X0 <- X
    Y0 <- Y
    X  <- X + Width/2
    Y  <- Y + Height/2
  })
  plus.end$conc <- predict.lm(scale.x,plus.end)
  plus.end$freq <- predict.lm(scale.y,plus.end)

  plus.fit <- lm(freq~conc,plus.end)
  plus.slope     <- coef(plus.fit)[[2]]
  plus.intercept <- coef(plus.fit)[[1]]

  minus.end <- within(minus.end, {
    X0 <- X
    Y0 <- Y
    X  <- X + Width/2
    Y  <- Y + Height/2
  })
  minus.end$conc <- predict.lm(scale.x,minus.end)
  minus.end$freq <- predict.lm(scale.y,minus.end)

  minus.fit <- lm(freq~conc,minus.end)
  minus.slope     <- coef(minus.fit)[[2]]
  minus.intercept <- coef(minus.fit)[[1]]
})

