source('./Common/analysis_tip.R')
source('./Common/salmon_88_analysis.R')

reread.data <- FALSE
make.plots  <- TRUE

sim.name <- 'presc7b'
plot.pfx <- 'presc7b'

if (reread.data || !exists('sim.data') || sim.data$sim.prefix != sim.name) {
  sim.data <- create.tippos(sim.name)
  sim.data <- add.rescue.analysis(sim.data)

  sim.data$plot.prefix <- plot.pfx
}

orig.wd <- getwd()
if (!dir.exists(plot.pfx)) {
  dir.create(plot.pfx)
}

setwd(plot.pfx)

if (make.plots) {
try(with(sim.data, {
       local({
         print.graphs(
           ggplot(subset(resc.analysis,
                         set %in% seq(9, 12) & resc.dist >= 0.5),
                         aes(x=factor(conc),
                             y=-(shorten.rate)*60,
                             color=factor(scanname))) +
             geom_boxplot() +
             guides(color=F) +
             geom_hline(yintercept=27,color='black',linetype=4) +
             labs(x='Concentration (uM)',
                  y='Rate of rapid shortening (micron/min)'),
           pdf.file=sprintf('%s_shortening_rate.pdf',plot.prefix))
       })

       local({
         resc.freqs <- merge(data.params.sets,
                             ddply(resc.analysis, .(set), function(df) {
                                     dt <- df$resc.time[ df$resc.dist > 0.5 ]

                                     num.resc <- length(dt)
                                     tot.resc.time <- sum(dt)
                                     resc.freq <- num.resc / tot.resc.time

                                     if (length(dt) >= 5) {
                                       b.dt <- boot(dt,function(df,ind) {
                                                      nr <- length(dt[ind])
                                                      t <- sum(dt[ind])
                                                      nr/t
                                       }, R=1000)
                                       if (sd(b.dt$t) < 1e-8) {
                                         resc.freq.lo <- resc.freq
                                         resc.freq.hi <- resc.freq
                                       } else {
                                         ci.df <- boot.ci(b.dt)
                                         resc.freq.lo <- ci.df$percent[4]
                                         resc.freq.hi <- ci.df$percent[5]
                                       }
                                     } else {
                                       resc.freq.lo <- resc.freq
                                       resc.freq.hi <- resc.freq
                                     }
                                     df <- data.frame(
                                                num.resc = num.resc,
                                                tot.resc.time = tot.resc.time,
                                                resc.freq = resc.freq,
                                                resc.freq.lo = resc.freq.lo,
                                                resc.freq.hi = resc.freq.hi)
                                     df
                             }),
                             by='set')

         print.graphs(
           ggplot(subset(resc.freqs, set %in% seq(9, 12)),
                  aes(x=conc, y=resc.freq, color=factor(scanname))) +
             geom_point() +
             geom_line() +
             geom_pointrange(aes(ymin=resc.freq.lo,ymax=resc.freq.hi)) +
             geom_point(data=salmon88.fig8$plus.end,
                        aes(y=freq,x=conc), inherit.aes=F, shape=4) +
             guides(color=F) +
             labs(x='Concentration (uM)', y='Rescue frequency'),
           pdf.file=sprintf('%s_resc_freq.pdf',plot.prefix))
       })
  }))
}

setwd(orig.wd)

